function spmat=discmat_te(eps,xi,dx,lambda)
%
%  Discretization matrix for TE modes of a 1D waveguide structure using 
%  the finite-difference approach of Vassallo (IEE Proceedings-J, v. 139, 
%  p. 137 (1992)). The formalism is here extended to allow for dielectric 
%  boundaries between both points i-1,i and i,i+1.
%
%  The routine takes as input a dielectric function, eps, a discretization
%  step dx, a wavelength lambda and a vector xi giving the exact positions
%  of the dielectric boundaries. Specifically, if a dielectric boundary is 
%  present at x lying between x_i and x_(i+1), then x=x_i+xi(i)*dx should 
%  hold. 
%
nx=length(eps);
k0=2*pi/lambda;
k02=k0^2;
ax=1/dx^2;
ad=2*ax;
spmat=spalloc(nx,nx,3*nx);
for i=2:nx-1
 if (eps(i-1)==eps(i))
  xim1=0.0;
  deltam1=0.0;
 else
  xim1=xi(i-1);
  deltam1=0.5*k02*xim1^2*(eps(i)-eps(i-1));
 end
 if (eps(i+1)==eps(i))
  xi0=0.0;
  delta0=0.0;
 else
  xi0=xi(i);
  delta0=0.5*k02*(1-xi0)^2*(eps(i)-eps(i+1));
 end
 deltai=-(delta0*(2*xi0+1)-deltam1*(3-2*xim1))/6.0;
 spmat(i,i-1)=ax-deltai;
 spmat(i,i+1)=ax+deltai;
 spmat(i,i)=-(ad+delta0+deltam1)+k02*eps(i);
end
spmat(1,1)=-ad+k02*eps(1);
spmat(nx,nx)=-ad+k02*eps(nx);
spmat(1,2)=ax;
spmat(nx,nx-1)=ax;
