function [eps,wid]=epsfiber(width,dx,a,ncore,nclad)
%
% MATLAB script to set up the dielectric permittivity of a step-index fiber
% in a (first-quadrant) quarter-domain structure. Fiber parameters are
% core radius a, core index ncore, cladding index nclad. Numerical parameters
% are domain width 'width' and discretization step dx. On output, the code
% returns a square dielectric distribution, along with a two-component array
% 'wid' giving the domain width in the x,y directions (they are identical here,
% but both components are given for compatibility with discmat_yee.m, which
% allow for different widths). The width is the distance from core center to
% the outer boundary of the domain. Note that the width returned may deviate
% slightly from the input width if the input is not an integer multiple of dx. 
%
% No dielectric averaging is performed in this routine, i.e. it implements
% the 'staircasing' approximation.
%
%
% Find a number of meshpoints giving approximately the desired domain width
%
nx=round(width/dx);
widthx=dx*nx;
wid=[widthx,widthx]
%
%  Set cladding epsilon
%
eps=ones(nx,nx)*nclad^2;
for m=1:nx
 for n=1:nx
%
% Calculate distance from lower left corner (fiber center)
%
  r=sqrt((m-1)^2+(n-1)^2)*dx;
%
% If distance is smaller than core radius, include the point in the fiber core
%
  if (r<a) 
   eps(n,m)=ncore^2;
  end
 end 
end
