function neff=neff_sif(lambda,nc,ncl,a)
%
% Script to calculate the effective index at the wavelength lambda for the 
% fundamental mode in a step-index fiber having core radius a, core index nc, 
% and cladding index ncl. The calculation is full-vectorial, and essentially
% exact, using the MATLAB root-finding procedure fsolve.
%
a=a/lambda;
lambda=1;
k0=2*pi/lambda;
dbeta=1.d-4;
beta0=nc*k0;
betamax=beta0;
options=optimset('TolFun',1.e-25,'TolX',1.e-25,'DiffMaxChange',dbeta);
exitflag=-1;
while (exitflag<0)
 [beta,fval,exitflag]=fsolve(@transcres,beta0,options,k0,nc,ncl,a,1,betamax);
 beta0=beta0-dbeta;
end
neff=beta/k0;
function delta=transcres(beta,k0,nc,ncl,a,n,betamax)
if (beta<=k0*ncl)
 delta=1.d20;
end
if (beta>=betamax)
 delta=1.d20;
end
if (beta>ncl*k0) && (beta<betamax)
 w=a*sqrt(beta^2-k0^2*ncl^2);
 u=a*sqrt(k0^2*nc^2-beta^2);
 dljn=0.5*(besselj(n-1,u)-besselj(n+1,u))/besselj(n,u);
 dlkn=-0.5*(besselk(n-1,w)+besselk(n+1,w))/besselk(n,w);
 delta=((dljn/u+dlkn/w)*(dljn/u+(ncl/nc)^2*dlkn/w)-n^2*(1/u^2+1/w^2)*(1/u^2+(ncl/nc/w)^2))^2;
end
