function [neff_te,neff_tm]=neff_slab(lambda,nl,nr,nc,d)
%
%  Exact effective index of the fundamental TE and TM modes in an asymmetric
%  slab waveguide. nc,nl,nr are the refractive indices of the core,
%  left cladding, and right cladding respectively, whereas d is the
%  core width and lambda the wavelength.
%
tol=1.e-13;
k0=2*pi/lambda;
beta_te=solve_fund(k0,nr,nl,nc,d,tol,0);
beta_tm=solve_fund(k0,nr,nl,nc,d,tol,1);
neff_te=beta_te/k0;
neff_tm=beta_tm/k0;
end
function betafin=solve_fund(k0,nr,nl,nc,d,tol,flag)
ncl=max(nl,nr);
dbeta=1.d-4*(nc-ncl)*k0;
beta=nc*k0-dbeta;
betaold=nc*k0;
betamax=nc*k0;
exitflag=-1;
[deltaold,kappaold,thetaold]=transc(betaold,k0,nl,nr,nc,d,flag);
while (exitflag<0)
 [delta,kappa,theta]=transc(beta,k0,nl,nr,nc,d,flag);
 if (delta*deltaold<0 && (kappa*d-pi/2)*(kappaold*d-pi/2)>0) && ((kappa*d+pi/2)*(kappaold*d+pi/2)>0 && theta*thetaold>0)
  delt=delta;
  beta2=beta;
  beta1=betaold;
  isign=1;
  while (abs(beta2-beta1)>tol)
   deltold=delt;
   betac=(beta1+beta2)/2.0;
   [delt,kappa,theta]=transc(betac,k0,nl,nr,nc,d,flag);
   if (deltold*delt*isign<0) 
    beta1=betac;
    isign=-1;
   else
    beta2=betac;
    isign=1;
   end
  end
  exitflag=1;
  betafin=betac;
 end
 if (beta<=k0*ncl) 
  exitflag=1;
  betafin=k0*ncl;
 end
 betaold=beta;
 beta=beta-dbeta;
 deltaold=delta;
 kappaold=kappa;
 thetaold=theta;
end
end
function [delta,kappa,theta]=transc(beta,k0,nl,nr,nc,d,flag);
if (flag==1)
 factl=(nc/nl)^2;
 factr=(nc/nr)^2;
else
 factl=1.0;
 factr=1.0;
end
gamma=sqrt(beta^2-k0^2*nl^2)*factl;
eta=sqrt(beta^2-k0^2*nr^2)*factr;
kappa=sqrt(k0^2*nc^2-beta^2);
theta=kappa^2-gamma*eta;
delta=tan(kappa*d)-kappa*(gamma+eta)/theta;
end
